# CHANGELOG

<!-- version list -->

## v1.0.2 (2026-03-09)

### Bug Fixes

- Ci/cd twine publish
  ([`0c05fac`](https://github.com/kennaruk/slimtsf/commit/0c05fac3f08061d7be98d3e7d6f9a37ef733061a))


## v1.0.0 (2026-03-09)

- Initial Release

## v1.0.1 (2026-03-09)

### Bug Fixes

- **CI/CD**: Correct env pypi key
  ([`fdbd0be`](https://github.com/kennaruk/slimtsf/commit/fdbd0be9c6987c320373867368e71b8f6e792eb2))


## v1.0.0 (2026-03-09)

- Initial Release
